/*
* @license Apache-2.0
*
* Copyright (c) 2024 The Stdlib Authors.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*    http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

import array2iterator = require( '@stdlib/array/to-iterator' );
import iterCuSome = require( './index' );


// TESTS //

// The function returns an iterator...
{
	iterCuSome( array2iterator( [ false, false, false, true, true ] ), 2 ); // $ExpectType Iterator
}

// The compiler throws an error if the function is provided a first argument which is not an iterator...
{
	iterCuSome( 'abc', 2 ); // $ExpectError
	iterCuSome( 123, 2 ); // $ExpectError
	iterCuSome( true, 2 ); // $ExpectError
	iterCuSome( false, 2 ); // $ExpectError
	iterCuSome( [], 2 ); // $ExpectError
	iterCuSome( {}, 2 ); // $ExpectError
}

// The compiler throws an error if the function is provided a second argument which is not a number...
{
	const it = array2iterator( [ false, false, false, true, true ] );

	iterCuSome( it, '2' ); // $ExpectError
	iterCuSome( it, true ); // $ExpectError
	iterCuSome( it, false ); // $ExpectError
	iterCuSome( it, null ); // $ExpectError
	iterCuSome( it, [] ); // $ExpectError
	iterCuSome( it, {} ); // $ExpectError
	iterCuSome( it, ( x: number ): number => x ); // $ExpectError
}

// The compiler throws an error if the function is provided an unsupported number of arguments...
{
	const it = array2iterator( [ false, false, false, true, true ] );

	iterCuSome(); // $ExpectError
	iterCuSome( it ); // $ExpectError
	iterCuSome( it, 2, {} ); // $ExpectError
}
